from .client import post_request as post_request
from .custom_field_model import CustomFieldModel as CustomFieldModel
from dataclasses import dataclass

@dataclass
class ContactPerson:
    firstname: str | None = ...
    lastname: str | None = ...
    def __init__(self, firstname=..., lastname=...) -> None: ...

@dataclass
class Contact(CustomFieldModel):
    company_name: str | None = ...
    address1: str | None = ...
    address2: str | None = ...
    zipcode: str | None = ...
    city: str | None = ...
    country: str | None = ...
    phone: str | None = ...
    delivery_method: str | None = ...
    customer_id: str | None = ...
    tax_number: str | None = ...
    firstname: str | None = ...
    lastname: str | None = ...
    chamber_of_commerce: str | None = ...
    bank_account: str | None = ...
    send_invoices_to_attention: str | None = ...
    send_invoices_to_email: str | None = ...
    send_estimates_to_attention: str | None = ...
    send_estimates_to_email: str | None = ...
    sepa_active: bool = ...
    sepa_iban: str | None = ...
    sepa_iban_account_name: str | None = ...
    sepa_bic: str | None = ...
    sepa_mandate_id: str | None = ...
    sepa_mandate_date: str | None = ...
    sepa_sequence_type: str | None = ...
    si_identifier_type: str | None = ...
    si_identifier: str | None = ...
    invoice_workflow_id: int | None = ...
    estimate_workflow_id: int | None = ...
    email_ubl: bool = ...
    direct_debit: bool = ...
    contact_person: ContactPerson | None = ...
    type: str | None = ...
    from_checkout: bool = ...
    @staticmethod
    def find_by_customer_id(customer_id: str) -> Contact: ...
    def __init__(self, id=..., company_name=..., address1=..., address2=..., zipcode=..., city=..., country=..., phone=..., delivery_method=..., customer_id=..., tax_number=..., firstname=..., lastname=..., chamber_of_commerce=..., bank_account=..., send_invoices_to_attention=..., send_invoices_to_email=..., send_estimates_to_attention=..., send_estimates_to_email=..., sepa_active=..., sepa_iban=..., sepa_iban_account_name=..., sepa_bic=..., sepa_mandate_id=..., sepa_mandate_date=..., sepa_sequence_type=..., si_identifier_type=..., si_identifier=..., invoice_workflow_id=..., estimate_workflow_id=..., email_ubl=..., direct_debit=..., contact_person=..., type=..., from_checkout=...) -> None: ...
