from .financial_mutation import FinancialMutation as FinancialMutation
from .model import MoneybirdModel as MoneybirdModel
from dataclasses import dataclass
from typing import Self

@dataclass
class FinancialStatement(MoneybirdModel):
    financial_account_id: str | None = ...
    reference: str | None = ...
    official_date: str | None = ...
    official_balance: str | None = ...
    importer_service: str | None = ...
    financial_mutations: list[FinancialMutation] = ...
    def load(self, id: int) -> None: ...
    @classmethod
    def find_by_id(cls, id: int) -> Self: ...
    def __init__(self, id=..., financial_account_id=..., reference=..., official_date=..., official_balance=..., importer_service=..., financial_mutations=...) -> None: ...
