from .model import MoneybirdModel as MoneybirdModel
from dataclasses import dataclass

@dataclass
class CustomField:
    id: int | None = ...
    value: str | None = ...
    def __init__(self, id=..., value=...) -> None: ...

class CustomFieldModel(MoneybirdModel):
    custom_fields: list[CustomField]
    def get_custom_field(self, field_id: int) -> str | None: ...
    def set_custom_field(self, field_id: int, value: str) -> None: ...
